Skip to content

Metal tvOS xcode16.0 b6

Rolf Bjarne Kvinge edited this page Aug 27, 2024 · 2 revisions

#Metal.framework https://github.com/xamarin/xamarin-macios/pull/20895

diff -ruN /Applications/Xcode_16.0.0-beta5.app/Contents/Developer/Platforms/AppleTVOS.platform/Developer/SDKs/AppleTVOS.sdk/System/Library/Frameworks/Metal.framework/Headers/MTLFunctionDescriptor.h /Applications/Xcode_16.0.0-beta6.app/Contents/Developer/Platforms/AppleTVOS.platform/Developer/SDKs/AppleTVOS.sdk/System/Library/Frameworks/Metal.framework/Headers/MTLFunctionDescriptor.h
--- /Applications/Xcode_16.0.0-beta5.app/Contents/Developer/Platforms/AppleTVOS.platform/Developer/SDKs/AppleTVOS.sdk/System/Library/Frameworks/Metal.framework/Headers/MTLFunctionDescriptor.h	2024-07-24 23:28:41
+++ /Applications/Xcode_16.0.0-beta6.app/Contents/Developer/Platforms/AppleTVOS.platform/Developer/SDKs/AppleTVOS.sdk/System/Library/Frameworks/Metal.framework/Headers/MTLFunctionDescriptor.h	2024-08-09 07:12:29
@@ -25,11 +25,13 @@
      */
     MTLFunctionOptionCompileToBinary API_AVAILABLE(macos(11.0), ios(14.0), tvos(16.0)) = 1 << 0,
     /**
      * @brief stores and tracks this function in a MetalScript
      * This flag is optional and only supported in the context of binary archives.
      * @discussion This flag is required for inspecting and consuming binary archives with specialized MTLFunctions via the metal-source tool. It is not required for recompilation, nor for storing functions in binary archives. Set this flag only if you intend to use metal-source on a serialized binary archive.
      */
-    MTLFunctionOptionStoreFunctionInMetalScript API_AVAILABLE(macos(14.0), ios(17.0)) = 1 << 1,
+    MTLFunctionOptionStoreFunctionInMetalPipelinesScript API_AVAILABLE(macos(15.0), ios(18.0)) = 1 << 1,
+    MTLFunctionOptionStoreFunctionInMetalScript API_DEPRECATED_WITH_REPLACEMENT("MTLFunctionOptionStoreFunctionInMetalPipelinesScript", macos(14.0, 15.0), ios(17.0, 18.0), tvos(17.0, 18.0)) = 1 << 1,
+    
     /**
          * @brief Function creation fails (i.e nil is returned) if:
          * - A lookup binary archive has been specified
@@ -25,11 +25,13 @@
     MTLFunctionOptionCompileToBinary API_AVAILABLE(macos(11.0), ios(14.0), tvos(16.0)) = 1 << 0,
     /**
-     * @brief stores and tracks this function in a MetalScript
+     * @brief stores and tracks this function in a Metal Pipelines Script
      * This flag is optional and only supported in the context of binary archives.
      * @discussion This flag is required for inspecting and consuming binary archives with specialized MTLFunctions via the metal-source tool. It is not required for recompilation, nor for storing functions in binary archives. Set this flag only if you intend to use metal-source on a serialized binary archive.
diff -ruN /Applications/Xcode_16.0.0-beta5.app/Contents/Developer/Platforms/AppleTVOS.platform/Developer/SDKs/AppleTVOS.sdk/System/Library/Frameworks/Metal.framework/Headers/MTLFunctionStitching.h /Applications/Xcode_16.0.0-beta6.app/Contents/Developer/Platforms/AppleTVOS.platform/Developer/SDKs/AppleTVOS.sdk/System/Library/Frameworks/Metal.framework/Headers/MTLFunctionStitching.h
--- /Applications/Xcode_16.0.0-beta5.app/Contents/Developer/Platforms/AppleTVOS.platform/Developer/SDKs/AppleTVOS.sdk/System/Library/Frameworks/Metal.framework/Headers/MTLFunctionStitching.h	2024-07-24 23:28:41
+++ /Applications/Xcode_16.0.0-beta6.app/Contents/Developer/Platforms/AppleTVOS.platform/Developer/SDKs/AppleTVOS.sdk/System/Library/Frameworks/Metal.framework/Headers/MTLFunctionStitching.h	2024-08-09 07:08:20
@@ -32,11 +32,11 @@
      */
     MTLStitchedLibraryOptionFailOnBinaryArchiveMiss    = 1 << 0,
     /**
      * @brief stores and tracks this library in a MetalScript
      * This flag is optional and only supported in the context of binary archives.
      * @discussion This flag is required for inspecting and consuming binary archives with stitched libraries via the metal-source tool. It is not required for recompilation, nor for storing stitched libraries in binary archives. Set this flag only if you intend to use metal-source on a serialized binary archive.
      */
-    MTLStitchedLibraryOptionStoreLibraryInMetalScript  = 1 << 1,
+    MTLStitchedLibraryOptionStoreLibraryInMetalPipelinesScript  = 1 << 1,
 } API_AVAILABLE(macos(15.0), ios(18.0));
 
 /*!
@@ -32,11 +32,11 @@
     MTLStitchedLibraryOptionFailOnBinaryArchiveMiss    = 1 << 0,
     /**
-     * @brief stores and tracks this library in a MetalScript
+     * @brief stores and tracks this library in a Metal Pipelines Script
      * This flag is optional and only supported in the context of binary archives.
      * @discussion This flag is required for inspecting and consuming binary archives with stitched libraries via the metal-source tool. It is not required for recompilation, nor for storing stitched libraries in binary archives. Set this flag only if you intend to use metal-source on a serialized binary archive.
Clone this wiki locally